@@ -1,12 +1,12 @@
 from uuid import uuid4
 from toot import cli
 
-from tests.integration.conftest import register_account
+from tests.integration.conftest import assert_ok, register_account
 
 
 def test_lists_empty(run):
     result = run(cli.lists.list)
-    assert result.exit_code == 0
+    assert_ok(result)
     assert result.stdout.strip() == "You have no lists defined."
 
 
@@ -17,37 +17,37 @@ def test_lists_empty_json(run_json):
 
 def test_list_create_delete(run):
     result = run(cli.lists.create, "banana")
-    assert result.exit_code == 0
+    assert_ok(result)
     assert result.stdout.strip() == '✓ List "banana" created.'
 
     result = run(cli.lists.list)
-    assert result.exit_code == 0
+    assert_ok(result)
     assert "banana" in result.stdout
 
     result = run(cli.lists.create, "mango")
-    assert result.exit_code == 0
+    assert_ok(result)
     assert result.stdout.strip() == '✓ List "mango" created.'
 
     result = run(cli.lists.list)
-    assert result.exit_code == 0
+    assert_ok(result)
     assert "banana" in result.stdout
     assert "mango" in result.stdout
 
     result = run(cli.lists.delete, "banana")
-    assert result.exit_code == 0
+    assert_ok(result)
     assert result.stdout.strip() == '✓ List "banana" deleted.'
 
     result = run(cli.lists.list)
-    assert result.exit_code == 0
+    assert_ok(result)
     assert "banana" not in result.stdout
     assert "mango" in result.stdout
 
     result = run(cli.lists.delete, "mango")
-    assert result.exit_code == 0
+    assert_ok(result)
     assert result.stdout.strip() == '✓ List "mango" deleted.'
 
     result = run(cli.lists.list)
-    assert result.exit_code == 0
+    assert_ok(result)
     assert result.stdout.strip() == "You have no lists defined."
 
     result = run(cli.lists.delete, "mango")
@@ -102,11 +102,11 @@ def test_list_add_remove(run, app):
     run(cli.accounts.follow, acc.username)
 
     result = run(cli.lists.add, list_name, acc.username)
-    assert result.exit_code == 0
+    assert_ok(result)
     assert result.stdout.strip() == f'✓ Added account "{acc.username}"'
 
     result = run(cli.lists.accounts, list_name)
-    assert result.exit_code == 0
+    assert_ok(result)
     assert acc.username in result.stdout
 
     # Account doesn't exist
@@ -120,11 +120,11 @@ def test_list_add_remove(run, app):
     assert result.stderr.strip() == "Error: List not found"
 
     result = run(cli.lists.remove, list_name, acc.username)
-    assert result.exit_code == 0
+    assert_ok(result)
     assert result.stdout.strip() == f'✓ Removed account "{acc.username}"'
 
     result = run(cli.lists.accounts, list_name)
-    assert result.exit_code == 0
+    assert_ok(result)
     assert result.stdout.strip() == "This list has no accounts."
 
 
