@@ -3,28 +3,13 @@ Helpers for testing.
 """
 
 import time
-from typing import Any, Callable
+from typing import Callable, TypeVar
 
 
-class MockResponse:
-    def __init__(self, response_data={}, ok=True, is_redirect=False):
-        self.response_data = response_data
-        self.content = response_data
-        self.ok = ok
-        self.is_redirect = is_redirect
-
-    def raise_for_status(self):
-        pass
-
-    def json(self):
-        return self.response_data
+T = TypeVar("T")
 
 
-def retval(val):
-    return lambda *args, **kwargs: val
-
-
-def run_with_retries(fn: Callable[..., Any]):
+def run_with_retries(fn: Callable[..., T]) -> T:
     """
     Run the the given function repeatedly until it finishes without raising an
     AssertionError. Sleep a bit between attempts. If the function doesn't
@@ -41,4 +26,4 @@ def run_with_retries(fn: Callable[..., Any]):
         except AssertionError:
             time.sleep(delay)
 
-    fn()
+    return fn()
