@@ -38,6 +38,10 @@ def find_account(app, user, account_name):
     raise ConsoleError("Account not found")
 
 
+def lookup(app, user, acct):
+    return http.get(app, user, "/api/v1/accounts/lookup", {"acct": acct})
+
+
 def _account_action(app, user, account, action) -> Response:
     url = f"/api/v1/accounts/{account}/{action}"
     return http.post(app, user, url)
@@ -482,6 +486,12 @@ def account_timeline_generator(app, user, account_name: str, replies=False, rebl
     return _timeline_generator(app, user, path, params)
 
 
+def account_timeline_generator_by_id(app, user, account_id: str, replies=False, reblogs=False, limit=20):
+    path = f"/api/v1/accounts/{account_id}/statuses"
+    params = {"limit": limit, "exclude_replies": not replies, "exclude_reblogs": not reblogs}
+    return _timeline_generator(app, user, path, params)
+
+
 def timeline_list_generator(app, user, list_id, limit=20):
     path = f"/api/v1/timelines/list/{list_id}"
     return _timeline_generator(app, user, path, {'limit': limit})
